@@ -35,7 +35,7 @@ class D1(C1):
 
     @property
     def info_registro_autocons(self):
-        tree = '{0}.InfoRegistoAutocons'.format(self._header)
+        tree = '{0}.InfoRegistroAutocons'.format(self._header)
         data = get_rec_attr(self.obj, tree, False)
         if data not in [None, False]:
             return InfoRegistroAutocons(data)
